==> okta-sdk-api-19.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/CsrSelfHrefHints.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * Describes allowed HTTP verbs for the &#x60;href&#x60;
 */
@ApiModel(description = "Describes allowed HTTP verbs for the `href`")
@JsonPropertyOrder({ CsrSelfHrefHints.JSON_PROPERTY_ALLOW })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class CsrSelfHrefHints implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
     * Gets or Sets allow
     */
    public enum AllowEnum {
        GET("GET"),

        DELETE("DELETE"),

        UNKNOWN_DEFAULT_OPEN_API("unknown_default_open_api");

        private String value;

        AllowEnum(String value) {
            this.value = value;
        }

        @JsonValue
        public String getValue() {
            return value;
        }

        @Override
        public String toString() {
            return String.valueOf(value);
        }

        @JsonCreator
        public static AllowEnum fromValue(String value) {
            for (AllowEnum b : AllowEnum.values()) {
                if (b.value.equals(value)) {
                    return b;
                }
            }
            return UNKNOWN_DEFAULT_OPEN_API;
        }
    }

    public static final String JSON_PROPERTY_ALLOW = "allow";
    private List<AllowEnum> allow = null;

    public CsrSelfHrefHints() {
    }

    public CsrSelfHrefHints allow(List<AllowEnum> allow) {

        this.allow = allow;
        return this;
    }

    public CsrSelfHrefHints addallowItem(AllowEnum allowItem) {
        if (this.allow == null) {
            this.allow = new ArrayList<>();
        }
        this.allow.add(allowItem);
        return this;
    }

    /**
     * Get allow
     *
     * @return allow
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ALLOW)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<AllowEnum> getAllow() {
        return allow;
    }

    @JsonProperty(JSON_PROPERTY_ALLOW)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setAllow(List<AllowEnum> allow) {
        this.allow = allow;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        CsrSelfHrefHints csrSelfHrefHints = (CsrSelfHrefHints) o;
        return Objects.equals(this.allow, csrSelfHrefHints.allow);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(allow);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class CsrSelfHrefHints {\n");
        sb.append("    allow: ").append(toIndentedString(allow)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/CsrSelfHrefHints.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * Describes allowed HTTP verbs for the &#x60;href&#x60;
 */
@ApiModel(description = "Describes allowed HTTP verbs for the `href`")
@JsonPropertyOrder({ CsrSelfHrefHints.JSON_PROPERTY_ALLOW })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class CsrSelfHrefHints implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
     * Gets or Sets allow
     */
    public enum AllowEnum {
        GET(String.valueOf("GET")),

        DELETE(String.valueOf("DELETE")),

        UNKNOWN_DEFAULT_OPEN_API(String.valueOf("unknown_default_open_api"));

        private String value;

        AllowEnum(String value) {
            this.value = value;
        }

        @JsonValue
        public String getValue() {
            return value;
        }

        @Override
        public String toString() {
            return String.valueOf(value);
        }

        @JsonCreator
        public static AllowEnum fromValue(String value) {
            for (AllowEnum b : AllowEnum.values()) {
                if (b.value.equals(value)) {
                    return b;
                }
            }
            return UNKNOWN_DEFAULT_OPEN_API;
        }
    }

    public static final String JSON_PROPERTY_ALLOW = "allow";
    private List<AllowEnum> allow = null;

    public CsrSelfHrefHints() {
    }

    public CsrSelfHrefHints allow(List<AllowEnum> allow) {

        this.allow = allow;
        return this;
    }

    public CsrSelfHrefHints addallowItem(AllowEnum allowItem) {
        if (this.allow == null) {
            this.allow = new ArrayList<>();
        }
        this.allow.add(allowItem);
        return this;
    }

    /**
     * Get allow
     *
     * @return allow
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ALLOW)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<AllowEnum> getAllow() {
        return allow;
    }

    @JsonProperty(JSON_PROPERTY_ALLOW)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setAllow(List<AllowEnum> allow) {
        this.allow = allow;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        CsrSelfHrefHints csrSelfHrefHints = (CsrSelfHrefHints) o;
        return Objects.equals(this.allow, csrSelfHrefHints.allow);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(allow);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class CsrSelfHrefHints {\n");
        sb.append("    allow: ").append(toIndentedString(allow)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
